@@ -52,7 +52,7 @@ struct Tga16Reader : public TgaReader
         if (s->getChar(&ch1) && s->getChar(&ch2)) {
             quint16 d = (int(ch1) & 0xFF) | ((int(ch2) & 0xFF) << 8);
             QRgb result = (d & 0x8000) ? 0xFF000000 : 0x00000000;
-            result |= (d & 0x7C00 << 6) | (d & 0x03E0 << 3) | (d & 0x001F);
+            result |= ((d & 0x7C00) << 6) | ((d & 0x03E0) << 3) | (d & 0x001F);
             return result;
         } else {
             return 0;
@@ -138,9 +138,7 @@ QTgaFile::QTgaFile(QIODevice *device)
         mErrorMessage = tr("Seek file/device for image read failed");
         return;
     }
-    int bytes = device->read((char*)mHeader, HeaderSize);
-    if (bytes != HeaderSize)
-    {
+    if (device->read(reinterpret_cast<char*>(mHeader), HeaderSize) != HeaderSize) {
         mErrorMessage = tr("Image header read failed");
         return;
     }
@@ -164,9 +162,7 @@ QTgaFile::QTgaFile(QIODevice *device)
         return;
     }
     char footer[FooterSize];
-    bytes = mDevice->read((char*)footer, FooterSize);
-    if (bytes != FooterSize)
-    {
+    if (mDevice->read(reinterpret_cast<char*>(footer), FooterSize) != FooterSize) {
         mErrorMessage = tr("Could not read footer");
     }
     if (qstrncmp(&footer[SignatureOffset], "TRUEVISION-XFILE", 16) != 0)
